====================
Fitting and plotting
====================

Interactive fitting
-------------------

Psi/Delta fitting
^^^^^^^^^^^^^^^^^
.. automodule:: elli.fitting.decorator_psi_delta
    :members:
    :show-inheritance:

Mueller matrix fitting
^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: elli.fitting.decorator_mmatrix
    :members:
    :show-inheritance:

Fitting base class
^^^^^^^^^^^^^^^^^^
.. automodule:: elli.fitting.decorator
    :members:
    :show-inheritance:

Parameter class
---------------
.. automodule:: elli.fitting.params_hist
    :members:
    :show-inheritance:

Plotting
--------

Mueller matrix
^^^^^^^^^^^^^^
.. automodule:: elli.plot.mueller_matrix
    :members:
    :show-inheritance:

Structure
^^^^^^^^^
.. automodule:: elli.plot.structure
    :members:
    :show-inheritance:








